/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.cropprotection.clm;

import com.sun.jersey.api.client.UniformInterfaceException;
import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.model.CommonModelService;
import nl.cloudfarming.client.model.Remedy;
import nl.cloudfarming.client.stock.RemedyProvider;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/**
 * Service for the cropProtection CLM web service
 * Because of the serviceProvider it is initialized once.
 * On initialization will load all the CropProtections from the web service and update or persist them
 * @author Merijn Zengers
 */
@ServiceProvider(service = RemedyProvider.class)
public final class CropProtectionClmService implements RemedyProvider {

    private CropProtectionMarshaller marshaller = new CropProtectionMarshaller();
    private static final AppLogger LOG = AppLogFactory.getLogger(CommonModelService.class);
    private static final String NO_CONNECTION_MESSAGE = NbBundle.getMessage(CropProtectionClmService.class, "no_connection_message");


    @Override
    public List<Remedy> getRemedies() {
      AuthorizationServiceLayer client = new AuthorizationServiceLayer();
        List<Remedy> returnList = new ArrayList<Remedy>(); 
        try{
        String name = "%";
        String response = client.getCrop(String.class, name);
        //FIXME: Add tests and add rest of mapping
        CropProtectionMessage cpm = marshaller.unMarshall(response);
        for (CropProtection cropProtection : cpm.getCropProtection()) {
            Remedy remedy = new Remedy();
            remedy.setAuthorizationNumber(cropProtection.getAuthorizationNumber());
            remedy.setAgentName(cropProtection.agent.getName());
            remedy.setApplicationMethod(cropProtection.applicationMethod);
            remedy.setSafetyTerm(cropProtection.getSafetyTerm());
            
            returnList.add(remedy);
        }

        client.close();
        } catch(UniformInterfaceException ex){
            LOG.info(NO_CONNECTION_MESSAGE);
        } catch(com.sun.jersey.api.client.ClientHandlerException e){
            LOG.info(NO_CONNECTION_MESSAGE);
        }
        return returnList;
    }

}
